@@ -36,9 +36,9 @@
 
 #ifndef lint
 #ifdef QUEUE
-static char sccsid[] = "@(#)queue.c	8.41 (Berkeley) 4/18/94 (with queueing)";
+static char sccsid[] = "@(#)queue.c	8.41.1.1 (Berkeley) 2/10/95 (with queueing)";
 #else
-static char sccsid[] = "@(#)queue.c	8.41 (Berkeley) 4/18/94 (without queueing)";
+static char sccsid[] = "@(#)queue.c	8.41.1.1 (Berkeley) 2/10/95 (without queueing)";
 #endif
 #endif /* not lint */
 
@@ -210,7 +210,7 @@ queueup(e, queueall, announce)
 
 	/* message from envelope, if it exists */
 	if (e->e_message != NULL)
-		fprintf(tfp, "M%s\n", e->e_message);
+		fprintf(tfp, "M%s\n", denlstring(e->e_message));
 
 	/* send various flag bits through */
 	p = buf;
@@ -224,14 +224,14 @@ queueup(e, queueall, announce)
 
 	/* $r and $s and $_ macro values */
 	if ((p = macvalue('r', e)) != NULL)
-		fprintf(tfp, "$r%s\n", p);
+		fprintf(tfp, "$r%s\n", denlstring(p));
 	if ((p = macvalue('s', e)) != NULL)
-		fprintf(tfp, "$s%s\n", p);
+		fprintf(tfp, "$s%s\n", denlstring(p));
 	if ((p = macvalue('_', e)) != NULL)
-		fprintf(tfp, "$_%s\n", p);
+		fprintf(tfp, "$_%s\n", denlstring(p));
 
 	/* output name of sender */
-	fprintf(tfp, "S%s\n", e->e_from.q_paddr);
+	fprintf(tfp, "S%s\n", denlstring(e->e_from.q_paddr));
 
 	/* output list of error recipients */
 	printctladdr(NULL, NULL);
@@ -240,7 +240,7 @@ queueup(e, queueall, announce)
 		if (!bitset(QDONTSEND|QBADADDR, q->q_flags))
 		{
 			printctladdr(q, tfp);
-			fprintf(tfp, "E%s\n", q->q_paddr);
+			fprintf(tfp, "E%s\n", denlstring(q->q_paddr));
 		}
 	}
 
@@ -251,7 +251,7 @@ queueup(e, queueall, announce)
 		    (queueall && !bitset(QDONTSEND|QBADADDR|QSENT, q->q_flags)))
 		{
 			printctladdr(q, tfp);
-			fprintf(tfp, "R%s\n", q->q_paddr);
+			fprintf(tfp, "R%s\n", denlstring(q->q_paddr));
 			if (announce)
 			{
 				e->e_to = q->q_paddr;
@@ -427,7 +427,7 @@ printctladdr(a, tfp)
 	else
 		uname = pw->pw_name;
 
-	fprintf(tfp, "C%s:%s\n", uname, a->q_paddr);
+	fprintf(tfp, "C%s:%s\n", uname, denlstring(a->q_paddr));
 }
 
 /*
